@@ -39,6 +39,11 @@ class Site(Site):
 
     auto_configure_logger_names = "atelier django lino lino_xl lino_noi"
 
+    def setup_features(self):
+        super().setup_features()
+        self.features.define_feature(
+            "cms_functionality", _("Public web content"), activate=True)
+
     def get_installed_apps(self):
         """Implements :meth:`lino.core.site.Site.get_installed_apps` for Lino
         Noi.
@@ -99,6 +104,10 @@ class Site(Site):
         yield 'lino_xl.lib.invoicing'
         yield 'lino_xl.lib.orders'
 
+        if self.features.has_feature('cms_functionality'):
+            yield 'lino_xl.lib.pages'
+            yield 'lino.modlib.publisher'
+
     def get_plugin_configs(self):
         yield super(Site, self).get_plugin_configs()
         yield ('tickets', 'end_user_model', 'contacts.Person')
